# A heading

Some text. More than one line.

::: {.notebook name="first_notebook"}
Start of `first_notebook` notebook

```{=html}
<div class="nb-links">
<a class="notebook-link" href=first_notebook.Rmd>Download notebook</a>
</div>
```

Here is a paragraph.

And another.

End of `first_notebook` notebook
:::

More text.

::: r
This is a block for the R version.
:::

Some thoughts.

::: r
This is another block for the R version.
:::

On the other hand:

::: python
This is a block for the Python version.
:::

The text continues; [This is *some text*]{.r}[More text]{.python}.
Continues.

Then we write: [more R]{.r}.

::: {.notebook name="second_notebook"}
Start of `second_notebook` notebook

```{=html}
<div class="nb-links">
<a class="notebook-link" href=second_notebook.Rmd>Download notebook</a>
</div>
```

Here, again, is a paragraph.

And, again, another.

End of `second_notebook` notebook
:::

End of page.
